#
# spec file for package python-jupyter_ipython
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
%bcond_without iptest
%if 0%{?is_opensuse}
%ifarch %{ix86}
%if 0%{?leap_version} == 420200
%bcond_with backends
%else
%bcond_without backends
%endif
%else
%bcond_without backends
%endif
%else
%if 0%{?sle_version} && 0%{sle_version} < 150000
%bcond_with backends
%else
%bcond_without backends
%endif
%endif
Name:           python-jupyter_ipython
Version:        6.5.0
Release:        2.5
Summary:        Rich architecture for interactive computing with Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/ipython/ipython
Source:         https://files.pythonhosted.org/packages/source/i/ipython/ipython-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/jupyter/qtconsole/4.0.0/qtconsole/resources/icon/JupyterConsole.svg
BuildRequires:  %{python_module backcall}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools >= 18.5}
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
Requires:       python-Pygments
Requires:       python-backcall
Requires:       python-decorator
Requires:       python-jedi >= 0.10
Requires:       python-pexpect
Requires:       python-pickleshare
Requires:       python-prompt_toolkit >= 1.0.4
Requires:       python-prompt_toolkit < 2
Requires:       python-simplegeneric > 0.8
Requires:       python-traitlets >= 4.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-docrepr
Recommends:     python-jupyter_ipykernel
Recommends:     python-jupyter_ipyparallel
Recommends:     python-jupyter_ipywidgets
Recommends:     python-jupyter_nbconvert
Recommends:     python-jupyter_nbformat
Recommends:     python-jupyter_notebook
Recommends:     python-jupyter_qtconsole
BuildArch:      noarch
%if %{with ico}
BuildRequires:  icoutils
%endif
%ifpython3
Provides:       IPython3 = %{version}
Obsoletes:      IPython3 < %{version}
Provides:       python3-IPython = %{version}
Obsoletes:      python3-IPython < %{version}
%endif
# typing is only built-in for later versions of python
%if 0%{?suse_version} <= 1320
Requires:       python-typing
%endif
%python_subpackages

%description
IPython provides a rich toolkit to help you make the
most out of using Python interactively. Its main
components are:

 * A powerful interactive Python shell
 * A Jupyter kernel to work with Python code in
   Jupyter notebooks and other interactive frontends.

The enhanced interactive Python shells have the
following main features:

 * Comprehensive object introspection.
 * Input history, persistent across sessions.
 * Caching of output results during a session with automatically
   generated references.
 * Extensible tab completion, with support by default for completion
   of python variables and keywords, filenames and function keywords.
 * Extensible system of ‘magic’ commands for controlling the
   environment and performing many tasks related either to IPython or
   the operating system.
 * A rich configuration system with easy switching between different
   setups (simpler than changing $PYTHONSTARTUP environment variables
   every time).
 * Session logging and reloading.
 * Extensible syntax processing for special purpose situations.
 * Access to the system shell with user-extensible alias system.
 * Easily embeddable in other Python programs and GUIs.
 * Integrated access to the pdb debugger and the Python profiler.

%package iptest
Summary:        Tools for testing packages that rely in %{name}
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python-matplotlib
Requires:       python-nose
Requires:       python-requests
Requires:       python-testpath

%description iptest
This package provides the iptest command, which is used for
testing software that uses %{name}.

%prep
%setup -q -n ipython-%{version}

%build
%python_build

%if %{with ico}
pushd scripts
icotool -x ipython.ico
icotool -x ipython_nb.ico
popd
%endif

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/ipython
%python_clone -a %{buildroot}%{_mandir}/man1/ipython.1

%if %{with iptest}
%python_clone -a %{buildroot}%{_bindir}/iptest
%else
rm %{buildroot}%{_bindir}/iptest*
%endif

%if %{have_python3} && ! 0%{?skip_python3}
ln -s %{_mandir}/man1/ipython-%{python3_bin_suffix}.1.gz %{buildroot}%{_mandir}/man1/ipython3.1.gz
%endif

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
%python_expand cp %{SOURCE1} %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/IPython-%{$python_bin_suffix}.svg
%if %{with ico}
# Install the icons
for x in 16 24 32 48 256 ; do
    mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${x}x${x}/apps/
    ipyf=(scripts/ipython_*_${x}x${x}x32.png)
    ipynbf=(scripts/ipython_nb_*_${x}x${x}x32.png)
    %python_expand cp ${ipyf[0]}   %{buildroot}%{_datadir}/icons/hicolor/${x}x${x}/apps/IPython-%{$python_bin_suffix}.png
    %python_expand cp ${ipynbf[0]} %{buildroot}%{_datadir}/icons/hicolor/${x}x${x}/apps/IPythonNotebook-%{$python_bin_suffix}.png
done
%endif

# Modify and install .desktop file
%{python_expand cp examples/IPython\ Kernel/ipython.desktop ipython-%{$python_bin_suffix}.desktop
desktop-file-edit --set-comment="Enhanced interactive Python %{$python_bin_suffix} shell" --set-name="ipython %{$python_bin_suffix}" --set-generic-name="IPython %{$python_bin_suffix}" --set-key="Exec" --set-value="ipython-%{$python_bin_suffix}" --set-icon="IPython-%{$python_bin_suffix}" ipython-%{$python_bin_suffix}.desktop
%suse_update_desktop_file -i -r ipython-%{$python_bin_suffix} "System;TerminalEmulator;"
}

# These can be run stand-alone, so make them executable rather than removing shebang
%{python_expand find %{buildroot}%{$python_sitelib} -type f -name "*.py" -exec sed -i "s|^#!%{_bindir}/env python$|#!%{__$python}|" {} \;
find %{buildroot}%{$python_sitelib} -type f -name "*.py" -exec sed -i "s|^#!%{_bindir}/python$|#!%{__$python}|" {} \;
find %{buildroot}%{$python_sitelib} -type f -name "*.py" -exec grep -q "#!%{__$python}" {} \; -exec chmod a+x {} \;

$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/IPython
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/IPython

%fdupes %{buildroot}%{$python_sitelib}
}

rm %{buildroot}%{_bindir}/ipython3
ln -s %{_bindir}/ipython-%{python3_bin_suffix} %{buildroot}%{_bindir}/ipython3

%if %{with iptest}
rm %{buildroot}%{_bindir}/iptest3
ln -s %{_bindir}/iptest-%{python3_bin_suffix} %{buildroot}%{_bindir}/iptest3
%endif

%post
%{python_install_alternative ipython ipython.1.gz}
%desktop_database_post
%icon_theme_cache_post

%post iptest
%python_install_alternative iptest

%postun
%python_uninstall_alternative ipython
%desktop_database_postun
%icon_theme_cache_postun

%postun iptest
%python_uninstall_alternative iptest

%files %{python_files}
%license COPYING.rst
%doc README.rst docs/source/about/license_and_copyright.rst
%python_alternative %{_bindir}/ipython
%python_alternative %{_mandir}/man1/ipython.1.gz
%python3_only %{_bindir}/ipython3
%python3_only %{_mandir}/man1/ipython3.1.gz
%{python_sitelib}/IPython/
%{python_sitelib}/ipython-%{version}-py*.egg-info
%{_datadir}/applications/ipython-%{python_bin_suffix}.desktop
%{_datadir}/icons/hicolor/scalable/apps/IPython-%{python_bin_suffix}.svg
%if %{with ico}
%{_datadir}/icons/hicolor/*x*/apps/IPython-%{python_bin_suffix}.png
%{_datadir}/icons/hicolor/*x*/apps/IPythonNotebook-%{python_bin_suffix}.png
%endif

%if %{with iptest}
%files %{python_files iptest}
%python_alternative %{_bindir}/iptest
%python3_only %{_bindir}/iptest3

%endif

%changelog
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to version 6.5.0
  * Autocompletion fix for modules with out __init__.py :ghpull:`11227`
  * update the %%pastebin magic to use dpaste.com instead og GitHub Gist which now requires authentication :ghpull:`11182`
  * Fix crash with multiprocessing :ghpull:`11185`
- Switch to using upstream documentation builds
* Sun Jul 22 2018 toddrme2178@gmail.com
- Not compatible with prompt_toolkit 2.x
* Fri May 18 2018 toddrme2178@gmail.com
- Update to version 6.4.0
  * Fix display object not emitting metadata :ghpull:`11106`
  * Comments failing Jedi test :ghpull:`11110`
- Remove upstream-included disable_jedi_in_tests.patch
* Thu May  3 2018 toddrme2178@gmail.com
- Add disable_jedi_in_tests.patch
  Upstream bug: https://github.com/ipython/ipython/issues/11103
  From: https://github.com/ipython/ipython/pull/11113
  Should be in next release
* Thu Apr 19 2018 toddrme2178@gmail.com
- Add backcall dependency
* Thu Apr 12 2018 arun@gmx.de
- update to version 6.3.1:
  * This is a bugfix release to switch the default completions back to
    IPython's own completion machinery. We discovered some problems
    with the completions from Jedi, including completing column names
    on pandas data frames.
- changes from version 6.3:
  * A new display class :class:`IPython.display.Code` can be used to
    display syntax highlighted code in a notebook (:ghpull:`10978`).
  * The :cellmagic:`html` magic now takes a "--isolated" option to put
    the content in an iframe (:ghpull:`10962`).
  * The code to find completions using the Jedi library has had
    various adjustments. This is still a work in progress, but we hope
    this version has fewer annoyances (:ghpull:`10956`,
    :ghpull:`10969`, :ghpull:`10999`, :ghpull:`11035`,
    :ghpull:`11063`, :ghpull:`11065`).
  * The *post* event callbacks are now always called, even when the
    execution failed (for example because of a "SyntaxError").
  * The execution info and result objects are now made available in
    the corresponding *pre* or *post* "*_run_cell" :doc:`event
    callbacks </config/callbacks>` in a backward compatible manner
    (:ghissue:`10774` and :ghpull:`10795`).
  * Performance with very long code cells (hundreds of lines) is
    greatly improved (:ghpull:`10898`). Further improvements are
    planned for IPython 7.
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Tue Oct  3 2017 arun@gmx.de
- update to version 6.2.1:
  * IPython 6.2.1 ships with two minor fixes leading to no completions
    when using Jedi 0.11+ :ghpull:`10829`, and crash on some linux
    system with virtualenv :ghpull:`10829`
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to version 6.2.0
  * Function signature in completions
  * Assignments return values
  * Recursive Call of ipdb
  * System Wide config
  * ProgressBar
  * Fix ``IPython.core.display:Pretty._repr_pretty_`` had the wrong signature.
  * :magic:`timeit` now give a correct ``SyntaxError`` if naked ``return`` used.
  * Prepare the ``:ipython:`` directive to be compatible with Sphinx 1.7.
  * Make IPython work with OpenSSL in FIPS mode; change hash algorithm of input
    from md5 to sha1.
  * Clear breakpoints before running any script with debugger.
  * Document that :magic:`profile` is deprecated, not to be confused with :magic:`prun`.
  * Limit default number of returned completions to 500.
* Wed Sep  6 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 6.1.0
  * Quotes in a filename are always escaped during tab-completion on non-Windows.
    :ghpull:`10069`
  * Variables now shadow magics in autocompletion. See :ghissue:`4877` and :ghpull:`10542`.
  * Added the ability to add parameters to alias_magic.
  * To suppress log state messages, you can now either use ``%%logstart -q``, pass
    ``--LoggingMagics.quiet=True`` on the command line, or set
    ``c.LoggingMagics.quiet=True`` in your configuration file.
  * An additional flag ``--TerminalInteractiveShell.term_title_format`` is
    introduced to allow the user to control the format of the terminal title.  It
    is specified as a python format string, and currently the only variable it
    will format is ``{cwd}``.
  * ``??``/``%%pinfo2`` will now show object docstrings if the source can't be retrieved. :ghpull:`10532`
  * ``IPython.display`` has gained a ``%%markdown`` cell magic. :ghpull:`10563`
  * ``%%config`` options can now be tab completed. :ghpull:`10555`
  * ``%%config`` with no arguments are now unique and sorted. :ghpull:`10548`
  * Completion on keyword arguments does not duplicate ``=`` sign if already present. :ghpull:`10547`
  * ``%%run -m <module>`` now ``<module>`` passes extra arguments to ``<module>``. :ghpull:`10546`
  * completer now understand "snake case auto complete": if ``foo_bar_kittens`` is
    a valid completion, I can type ``f_b<tab>`` will complete to it. :ghpull:`10537`
  * tracebacks are better standardized and will compress `/path/to/home` to `~`. :ghpull:`10515`
  * ``TerminalInteractiveShell`` is configurable and can be configured to
    (re)-use the readline interface.
  * objects can now define a ``_repr_mimebundle_``
  * Execution heuristics improve for single line statements
  * ``display()`` can now return a display id to update display areas.
- Update to version 6.0.0
  * A major improvement in the completion machinery which is now capable of
    completing non-executed code.
  * stop compatibility with Python 2, which is still supported on the bugfix
    only 5.x branch.
  * Configurable TerminalInteractiveShell, readline interface
  * The :cellmagic:`capture` magic can now capture the result of a cell (from
    an expression on the last line), as well as printed and displayed output.
  * Pressing Ctrl-Z in the terminal debugger now suspends IPython, as it
    already does in the main terminal prompt.
  * Autoreload can now reload ``Enum``.
  * IPython.display has gained a :any:`GeoJSON <IPython.display.GeoJSON>`
    object.
* Fri Aug 11 2017 toddrme2178@gmail.com
- Update to version 5.4.1
  * Released a few hours after 5.4, fix a crash when
    ``backports.shutil-get-terminal-size`` is not installed. :ghissue:`10629`
- Update to version 5.4
  * Configurable TerminalInteractiveShell
  * Define ``_repr_mimebundle_``
  * Execution Heuristics
  * Implement Display IDs
  * Display function
  * ``_mp_main_`` is not reloaded which fixes issues with multiprocessing.
    :ghpull:`10523`
  * Use user colorscheme in Pdb as well :ghpull:`10479`
  * Faster shutdown. :ghpull:`10408`
  * Fix a crash in reverse search. :ghpull:`10371`
  * added ``Completer.backslash_combining_completions`` boolean option to
    deactivate backslash-tab completion that may conflict with windows path.
- Fix building on platforms without icoutils
* Thu Jul 13 2017 toddrme2178@gmail.com
- Fix shebang rpmint errors.
* Mon Apr 24 2017 toddrme2178@gmail.com
- Add note about LTS status and the end of Python 2 support.
- Add python2- provides.
- Neither HTML nor PDF documentation will ever work again,
  so drop it.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Install icons.
- Install .desktop file.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to IPython 5.3
  * Fix a bug in ``set_next_input`` leading to a crash of terminal IPython.
    :ghpull:`10231`, :ghissue:`10296`, :ghissue:`10229`
  * Always wait for editor inputhook for terminal IPython :ghpull:`10239`,
    :ghpull:`10240`
  * Disable ``_ipython_display_`` in terminal :ghpull:`10249`, :ghpull:`10274`
  * Update terminal colors to be more visible by default on windows
    :ghpull:`10260`, :ghpull:`10238`, :ghissue:`10281`
  * Add Ctrl-Z shortcut (suspend) in terminal debugger :ghpull:`10254`,
    :ghissue:`10273`
  * Indent on new line by looking at the text before the cursor :ghpull:`10264`,
    :ghpull:`10275`, :ghissue:`9283`
  * Update QtEventloop integration to fix some matplotlib integration issues
    :ghpull:`10201`, :ghpull:`10311`, :ghissue:`10201`
  * Respect completions display style in terminal debugger :ghpull:`10305`,
    :ghpull:`10313`
  * Add a config option ``TerminalInteractiveShell.extra_open_editor_shortcuts``
    to enable extra shortcuts to open the input in an editor. These are :kbd:`v`
    in vi mode, and :kbd:`C-X C-E` in emacs mode (:ghpull:`10330`).
    The :kbd:`F2` shortcut is always enabled.
- Update to IPython 5.2.2
  * Fix error when starting with ``IPCompleter.limit_to__all__`` configured.
- Update to IPython 5.2.1
  * Fix tab completion in the debugger. :ghpull:`10223`
- Update to IPython 5.2
  * restore IPython's debugger to raise on quit. :ghpull:`10009`
  * The configuration value ``c.TerminalInteractiveShell.highlighting_style`` can
    now directly take a class argument for custom color style. :ghpull:`9848`
  * Correctly handle matplotlib figures dpi :ghpull:`9868`
  * Deprecate ``-e`` flag for the ``%%notebook`` magic that had no effects.
    :ghpull:`9872`
  * You can now press F2 while typing at a terminal prompt to edit the contents
    in your favourite terminal editor. Set the :envvar:`EDITOR` environment
    variable to pick which editor is used. :ghpull:`9929`
  * sdists will now only be ``.tar.gz`` as per upstream PyPI requirements.
    :ghpull:`9925`
  * :any:`IPython.core.debugger` have gained a ``set_trace()`` method for
    convenience. :ghpull:`9947`
  * The 'smart command mode' added to the debugger in 5.0 was removed, as more
    people preferred the previous behaviour. Therefore, debugger commands such as
    ``c`` will act as debugger commands even when ``c`` is defined as a variable.
    :ghpull:`10050`
  * Fixes OS X event loop issues at startup, :ghpull:`10150`
  * Deprecate the ``%%autoindent`` magic. :ghpull:`10176`
  * Emit a :any:`DeprecationWarning` when setting the deprecated
    ``limit_to_all`` option of the completer. :ghpull:`10198`
  * The :cellmagic:`capture` magic can now capture the result of a cell (from an
    expression on the last line), as well as printed and displayed output.
    :ghpull:`9851`.
- Update to IPython 5.1
  * Broken ``%%timeit`` on Python2 due to the use of ``__qualname__``. :ghpull:`9804`
  * Restore ``%%gui qt`` to create and return a ``QApplication`` if necessary. :ghpull:`9789`
  * Don't set terminal title by default. :ghpull:`9801`
  * Preserve indentation when inserting newlines with ``Ctrl-O``. :ghpull:`9770`
  * Restore completion in debugger. :ghpull:`9785`
  * Deprecate ``IPython.core.debugger.Tracer()`` in favor of simpler, newer, APIs. :ghpull:`9731`
  * Restore ``NoOpContext`` context manager removed by mistake, and add `DeprecationWarning`. :ghpull:`9765`
  * Add option allowing ``Prompt_toolkit`` to use 24bits colors. :ghpull:`9736`
  * Fix for closing interactive matplotlib windows on OS X. :ghpull:`9854`
  * An embedded interactive shell instance can be used more than once. :ghpull:`9843`
  * More robust check for whether IPython is in a terminal. :ghpull:`9833`
  * Better pretty-printing of dicts on PyPy. :ghpull:`9827`
  * Some coloured output now looks better on dark background command prompts in Windows.
    :ghpull:`9838`
  * Improved tab completion of paths on Windows . :ghpull:`9826`
  * Fix tkinter event loop integration on Python 2 with ``future`` installed. :ghpull:`9824`
  * Restore ``Ctrl-\`` as a shortcut to quit IPython.
  * Make ``get_ipython()`` accessible when modules are imported by startup files. :ghpull:`9818`
  * Add support for running directories containing a ``__main__.py`` file with the
    ``ipython`` command. :ghpull:`9813`
- Update to IPython 5.0
  + IPython 5 features a major upgrade to the terminal interface, bringing live
    syntax highlighting as you type, proper multiline editing and multiline paste,
    and tab completions that don't clutter up your history.
  + Backwards incompatible changes
  * The ``%%install_ext`` magic function, deprecated since 4.0, has now been deleted.
    You can distribute and install extensions as packages on PyPI.
  * Callbacks registered while an event is being handled will now only be called
    for subsequent events; previously they could be called for the current event.
    Similarly, callbacks removed while handling an event *will* always get that
    event. See :ghissue:`9447` and :ghpull:`9453`.
  * Integration with pydb has been removed since pydb development has been stopped
    since 2012, and pydb is not installable from PyPI.
  * The ``autoedit_syntax`` option has apparently been broken for many years.
    It has been removed.
  * The overhaul of the terminal interface will probably cause a range of minor
    issues for existing users.
  * IPython no longer uses readline configuration (``~/.inputrc``). We hope that
    the functionality you want (e.g. vi input mode) will be available by configuring
    IPython directly (see :doc:`/config/options/terminal`).
  * The ``PromptManager`` class has been removed, and the prompt machinery simplified.
  * There are new options to configure the colours used in syntax highlighting.
    We have tried to integrate them with our classic  ``--colors`` option and
    ``%%colors`` magic, but there's a mismatch in possibilities, so some configurations
    may produce unexpected results. See :ref:`termcolour` for more information.
  * The new interface is not compatible with Emacs 'inferior-shell' feature. To
    continue using this, add the ``--simple-prompt`` flag to the command Emacs
    runs. This flag disables most IPython features, relying on Emacs to provide
    things like tab completion.
  + Provisional Changes
  * When running via the Jupyter notebook interfaces, or other compatible client,
    you can enable rich documentation experimental functionality:
    When the ``docrepr`` package is installed setting the boolean flag
    ``InteractiveShell.sphinxify_docstring`` to ``True``, will process the various
    object through sphinx before displaying them (see the ``docrepr`` package
    documentation for more information.
  + Deprecated Features
  * ``hooks.fix_error_editor`` seems unused and is pending deprecation.
  * `IPython/core/excolors.py:ExceptionColors` is  deprecated.
  * `IPython.core.InteractiveShell:write()` is deprecated; use `sys.stdout` instead.
  * `IPython.core.InteractiveShell:write_err()` is deprecated; use `sys.stderr` instead.
  * The `formatter` keyword argument to `Inspector.info` in `IPython.core.oinspec` has no effect.
  * The `global_ns` keyword argument of IPython Embed was deprecated, and has no effect. Use `module` keyword argument instead.
- Update to IPython 4.2
  * Fix ``ipython -i`` on errors, which was broken in 4.1.
  * The delay meant to highlight deprecated commands that have moved to jupyter has been removed.
  * Improve compatibility with future versions of traitlets and matplotlib.
  * Use stdlib :func:`python:shutil.get_terminal_size` to measure terminal width when displaying tracebacks
    (provided by ``backports.shutil_get_terminal_size`` on Python 2).
- Update to IPython 4.1.2
  * fixes installation issues with some versions of setuptools.
* Thu Mar 16 2017 jmatejek@suse.com
- do not Recommend jupyter_nbconvert (which pulls in texlive)
* Wed Feb 17 2016 toddrme2178@gmail.com
- specfile:
  * update copyright year
  * Simplify tests for determining whether to build pdf documentation
- update to version 4.1.1:
  * Backport #9209: Don't import IPython to check version number in
    setup
- Update to 4.1.0
  * Release February, 2016. IPython 4.1 contain mostly bug fixes.
    It though contain a few improvement.
  * IPython debugger (IPdb) now supports the number of context
    lines for the where (and w) commands. The context keyword is
    also available in various APIs. See PR :ghpull:`9097`
  * YouTube video will now show thumbnail when exported to a media
    that do not support video. (:ghpull:`9086`)
  * Add warning when running ipython <subcommand> when subcommand
    is deprecated. jupyter should now be used.
  * Code in %%pinfo (also known as ??) are now highlighter
    (:ghpull:`8947`)
  * %%aimport now support module completion. (:ghpull:`8884`)
  * ipdb output is now colored ! (:ghpull:`8842`)
  * Add ability to transpose columns for completion:
    (:ghpull:`8748`)
  * Many many docs improvements and bug fixes
- update to version 4.0.3:
  * Python 3.5 bug in that could crash during shutdown, triggered by
    deprecations in traitlets 4.1.
  * Typo in deprecation message for nbconvert
- update to version 4.0.2:
  * Fix backward-compatiblity shim for "IPython.Config", which
    should have been deprecated instead of removed. This will be
    removed in 5.0.
- update to version 4.0.1:
  * Installation on some systems
  * Compatibility with CPython 3.4.4
  * Compatibility with Qt5
* Thu Oct  1 2015 toddrme2178@gmail.com
- Build documentation
  This is in a separate spec file to avoid dependency loops
- Obsolete IPython
- Split the iptest executable into its own subpackage
  This has a bunch of testing dependencies that are not otherwise
  necessary.
* Fri Aug 21 2015 toddrme2178@gmail.com
- Add conflict with older versions of IPython
* Mon Aug 17 2015 toddrme2178@gmail.com
- Initial version
